==> jahia-impl-8.0.2.0-sources.jar: org/jahia/services/importexport/ImportFileUpdater.java <==
/*
 * ==========================================================================================
 * =                   JAHIA'S DUAL LICENSING - IMPORTANT INFORMATION                       =
 * ==========================================================================================
 *
 *                                 http://www.jahia.com
 *
 *     Copyright (C) 2002-2020 Jahia Solutions Group SA. All rights reserved.
 *
 *     THIS FILE IS AVAILABLE UNDER TWO DIFFERENT LICENSES:
 *     1/GPL OR 2/JSEL
 *
 *     1/ GPL
 *     ==================================================================================
 *
 *     IF YOU DECIDE TO CHOOSE THE GPL LICENSE, YOU MUST COMPLY WITH THE FOLLOWING TERMS:
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 *
 *     2/ JSEL - Commercial and Supported Versions of the program
 *     ===================================================================================
 *
 *     IF YOU DECIDE TO CHOOSE THE JSEL LICENSE, YOU MUST COMPLY WITH THE FOLLOWING TERMS:
 *
 *     Alternatively, commercial and supported versions of the program - also known as
 *     Enterprise Distributions - must be used in accordance with the terms and conditions
 *     contained in a separate written agreement between you and Jahia Solutions Group SA.
 *
 *     If you are unsure which license is appropriate for your use,
 *     please contact the sales department at sales@jahia.com.
 */
package org.jahia.services.importexport;

import org.jahia.commons.Version;

import java.io.File;

/**
 * Class used to update import file based on the originating version and build number
 */
public abstract class ImportFileUpdater {

    private ImportUpdateService importUpdateService;

    /**
     * Method used to determine if this import must be updated
     * @param version
     * @param buildNumber
     * @return true if this updater is applicable on an import originating from the specified version and build number
     */
    public abstract boolean mustUpdate(Version version, int buildNumber);

    /**
     * Method used to update an import zip file
     * @param importFile
     * @param fileName
     * @param fileType
     * @return the updated zip file
     */
    public abstract File updateImport(File importFile, String fileName, String fileType);

    public void init() {
        importUpdateService.registerUpdater(this);
    }

    public void destroy() {
        importUpdateService.unregisterUpdater(this);
    }

    public void setImportUpdateService(ImportUpdateService importUpdateService) {
        this.importUpdateService = importUpdateService;
    }
}

==> jahia-impl-8.1.0.0-sources.jar: org/jahia/services/importexport/ImportFileUpdater.java <==
/*
 * ==========================================================================================
 * =                   JAHIA'S DUAL LICENSING - IMPORTANT INFORMATION                       =
 * ==========================================================================================
 *
 *                                 http://www.jahia.com
 *
 *     Copyright (C) 2002-2020 Jahia Solutions Group SA. All rights reserved.
 *
 *     THIS FILE IS AVAILABLE UNDER TWO DIFFERENT LICENSES:
 *     1/GPL OR 2/JSEL
 *
 *     1/ GPL
 *     ==================================================================================
 *
 *     IF YOU DECIDE TO CHOOSE THE GPL LICENSE, YOU MUST COMPLY WITH THE FOLLOWING TERMS:
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 *
 *     2/ JSEL - Commercial and Supported Versions of the program
 *     ===================================================================================
 *
 *     IF YOU DECIDE TO CHOOSE THE JSEL LICENSE, YOU MUST COMPLY WITH THE FOLLOWING TERMS:
 *
 *     Alternatively, commercial and supported versions of the program - also known as
 *     Enterprise Distributions - must be used in accordance with the terms and conditions
 *     contained in a separate written agreement between you and Jahia Solutions Group SA.
 *
 *     If you are unsure which license is appropriate for your use,
 *     please contact the sales department at sales@jahia.com.
 */
package org.jahia.services.importexport;

import org.jahia.commons.Version;

import java.io.File;

/**
 * Class used to update import file based on the originating version and build number
 */
public abstract class ImportFileUpdater {

    private ImportUpdateService importUpdateService;

    /**
     * Method used to determine if this import must be updated
     * @param version
     * @param buildNumber
     * @return true if this updater is applicable on an import originating from the specified version and build number
     */
    public abstract boolean mustUpdate(Version version);

    /**
     * Method used to update an import zip file
     * @param importFile
     * @param fileName
     * @param fileType
     * @return the updated zip file
     */
    public abstract File updateImport(File importFile, String fileName, String fileType);

    public void init() {
        importUpdateService.registerUpdater(this);
    }

    public void destroy() {
        importUpdateService.unregisterUpdater(this);
    }

    public void setImportUpdateService(ImportUpdateService importUpdateService) {
        this.importUpdateService = importUpdateService;
    }
}
